@@ -27,8 +27,11 @@ macro_rules! skip_assert_initialized {
 #[allow(non_snake_case)]
 #[allow(clippy::use_self)]
 mod auto;
+pub use crate::auto::functions::*;
 pub use crate::auto::*;
 
+pub mod subclass;
+
 pub mod rtp_buffer;
 pub use crate::rtp_buffer::{compare_seqnum, RTPBuffer};
 #[cfg(any(feature = "v1_20", feature = "dox"))]
